# Importing production modules // Meant for production branch
from datetime import datetime
# Importing production modules

# Default Functions Calling
Today = datetime.today().strftime('%Y-%m-%d')
NOW = datetime.now()
CURRENT_TIME = NOW.strftime("%H:%M:%S")
# Default Functions Calling
